# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class QuerySessionInfoResponseBody(DaraModel):
    def __init__(
        self,
        query_resource_info_list: List[main_models.QuerySessionInfoResponseBodyQueryResourceInfoList] = None,
        request_id: str = None,
        total: int = None,
    ):
        self.query_resource_info_list = query_resource_info_list
        self.request_id = request_id
        self.total = total

    def validate(self):
        if self.query_resource_info_list:
            for v1 in self.query_resource_info_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['queryResourceInfoList'] = []
        if self.query_resource_info_list is not None:
            for k1 in self.query_resource_info_list:
                result['queryResourceInfoList'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total is not None:
            result['total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.query_resource_info_list = []
        if m.get('queryResourceInfoList') is not None:
            for k1 in m.get('queryResourceInfoList'):
                temp_model = main_models.QuerySessionInfoResponseBodyQueryResourceInfoList()
                self.query_resource_info_list.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('total') is not None:
            self.total = m.get('total')

        return self

class QuerySessionInfoResponseBodyQueryResourceInfoList(DaraModel):
    def __init__(
        self,
        session_id: str = None,
        status: str = None,
    ):
        self.session_id = session_id
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.session_id is not None:
            result['sessionId'] = self.session_id

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('sessionId') is not None:
            self.session_id = m.get('sessionId')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class ListAgentsResponseBody(DaraModel):
    def __init__(
        self,
        list: List[main_models.ListAgentsResponseBodyList] = None,
        request_id: str = None,
        success: bool = None,
        total: int = None,
    ):
        self.list = list
        self.request_id = request_id
        self.success = success
        self.total = total

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['list'] = []
        if self.list is not None:
            for k1 in self.list:
                result['list'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.success is not None:
            result['success'] = self.success

        if self.total is not None:
            result['total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.list = []
        if m.get('list') is not None:
            for k1 in m.get('list'):
                temp_model = main_models.ListAgentsResponseBodyList()
                self.list.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('success') is not None:
            self.success = m.get('success')

        if m.get('total') is not None:
            self.total = m.get('total')

        return self

class ListAgentsResponseBodyList(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        agent_name: str = None,
        agent_scene: str = None,
        characters_description: str = None,
        enable_interaction: int = None,
        industry: str = None,
        online_search: bool = None,
        owner: str = None,
        reference_url: str = None,
        status: int = None,
        text_style: str = None,
        viewer: str = None,
    ):
        self.agent_id = agent_id
        self.agent_name = agent_name
        self.agent_scene = agent_scene
        self.characters_description = characters_description
        self.enable_interaction = enable_interaction
        self.industry = industry
        self.online_search = online_search
        self.owner = owner
        self.reference_url = reference_url
        self.status = status
        self.text_style = text_style
        self.viewer = viewer

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.agent_name is not None:
            result['agentName'] = self.agent_name

        if self.agent_scene is not None:
            result['agentScene'] = self.agent_scene

        if self.characters_description is not None:
            result['charactersDescription'] = self.characters_description

        if self.enable_interaction is not None:
            result['enableInteraction'] = self.enable_interaction

        if self.industry is not None:
            result['industry'] = self.industry

        if self.online_search is not None:
            result['onlineSearch'] = self.online_search

        if self.owner is not None:
            result['owner'] = self.owner

        if self.reference_url is not None:
            result['referenceUrl'] = self.reference_url

        if self.status is not None:
            result['status'] = self.status

        if self.text_style is not None:
            result['textStyle'] = self.text_style

        if self.viewer is not None:
            result['viewer'] = self.viewer

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('agentName') is not None:
            self.agent_name = m.get('agentName')

        if m.get('agentScene') is not None:
            self.agent_scene = m.get('agentScene')

        if m.get('charactersDescription') is not None:
            self.characters_description = m.get('charactersDescription')

        if m.get('enableInteraction') is not None:
            self.enable_interaction = m.get('enableInteraction')

        if m.get('industry') is not None:
            self.industry = m.get('industry')

        if m.get('onlineSearch') is not None:
            self.online_search = m.get('onlineSearch')

        if m.get('owner') is not None:
            self.owner = m.get('owner')

        if m.get('referenceUrl') is not None:
            self.reference_url = m.get('referenceUrl')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('textStyle') is not None:
            self.text_style = m.get('textStyle')

        if m.get('viewer') is not None:
            self.viewer = m.get('viewer')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AddTextFeedbackRequest(DaraModel):
    def __init__(
        self,
        content: str = None,
        quality: int = None,
        text_id: int = None,
    ):
        self.content = content
        self.quality = quality
        self.text_id = text_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.content is not None:
            result['content'] = self.content

        if self.quality is not None:
            result['quality'] = self.quality

        if self.text_id is not None:
            result['textId'] = self.text_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('content') is not None:
            self.content = m.get('content')

        if m.get('quality') is not None:
            self.quality = m.get('quality')

        if m.get('textId') is not None:
            self.text_id = m.get('textId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class SelectImageTaskResponseBody(DaraModel):
    def __init__(
        self,
        error_message: str = None,
        failed: str = None,
        generation_source: str = None,
        gmt_create: str = None,
        image_infos: List[main_models.SelectImageTaskResponseBodyImageInfos] = None,
        request_id: str = None,
        scene: str = None,
        status: str = None,
        subtask_processing: str = None,
        success: str = None,
        total: str = None,
    ):
        self.error_message = error_message
        self.failed = failed
        self.generation_source = generation_source
        self.gmt_create = gmt_create
        self.image_infos = image_infos
        # Id of the request
        self.request_id = request_id
        self.scene = scene
        self.status = status
        self.subtask_processing = subtask_processing
        self.success = success
        self.total = total

    def validate(self):
        if self.image_infos:
            for v1 in self.image_infos:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.error_message is not None:
            result['errorMessage'] = self.error_message

        if self.failed is not None:
            result['failed'] = self.failed

        if self.generation_source is not None:
            result['generationSource'] = self.generation_source

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        result['imageInfos'] = []
        if self.image_infos is not None:
            for k1 in self.image_infos:
                result['imageInfos'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.scene is not None:
            result['scene'] = self.scene

        if self.status is not None:
            result['status'] = self.status

        if self.subtask_processing is not None:
            result['subtaskProcessing'] = self.subtask_processing

        if self.success is not None:
            result['success'] = self.success

        if self.total is not None:
            result['total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('errorMessage') is not None:
            self.error_message = m.get('errorMessage')

        if m.get('failed') is not None:
            self.failed = m.get('failed')

        if m.get('generationSource') is not None:
            self.generation_source = m.get('generationSource')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        self.image_infos = []
        if m.get('imageInfos') is not None:
            for k1 in m.get('imageInfos'):
                temp_model = main_models.SelectImageTaskResponseBodyImageInfos()
                self.image_infos.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('scene') is not None:
            self.scene = m.get('scene')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('subtaskProcessing') is not None:
            self.subtask_processing = m.get('subtaskProcessing')

        if m.get('success') is not None:
            self.success = m.get('success')

        if m.get('total') is not None:
            self.total = m.get('total')

        return self

class SelectImageTaskResponseBodyImageInfos(DaraModel):
    def __init__(
        self,
        custom_image_url: str = None,
        gmt_create: str = None,
        image_h: str = None,
        image_w: str = None,
    ):
        self.custom_image_url = custom_image_url
        self.gmt_create = gmt_create
        self.image_h = image_h
        self.image_w = image_w

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.custom_image_url is not None:
            result['customImageUrl'] = self.custom_image_url

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.image_h is not None:
            result['imageH'] = self.image_h

        if self.image_w is not None:
            result['imageW'] = self.image_w

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('customImageUrl') is not None:
            self.custom_image_url = m.get('customImageUrl')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('imageH') is not None:
            self.image_h = m.get('imageH')

        if m.get('imageW') is not None:
            self.image_w = m.get('imageW')

        return self

